@@ -1,13 +1,13 @@
 package Catmandu::AlephX::Op::CircStatus;
 use Catmandu::Sane;
-use Data::Util qw(:check);
+use Catmandu::Util qw(:check);
 use Moo;
 
 with('Catmandu::AlephX::Response');
 
 has item_data => (
   is => 'ro',
-  isa => sub { array_ref($_[0]); }
+  isa => sub { check_array_ref($_[0]); }
 );
 
 sub op { 'circ-status' }
@@ -27,7 +27,8 @@ sub parse {
   __PACKAGE__->new(
     item_data => \@item_data,
     session_id => $xpath->findvalue("/$op/session-id"),
-    error => $xpath->findvalue("/$op/error")
+    errors => $class->parse_errors($xpath),
+    content_ref => $str_ref
   );
   
 }
