@@ -1,6 +1,6 @@
 package Catmandu::AlephX::Op::ReadItem;
 use Catmandu::Sane;
-use Data::Util qw(:check :validate);
+use Catmandu::Util qw(:check :is);
 use Moo;
 
 with('Catmandu::AlephX::Response');
@@ -9,13 +9,10 @@ has z30 => (
   is => 'ro',
   lazy => 1,
   isa => sub{
-    array_ref($_[0]);
-    for(@{ $_[0] }){
-      hash_ref($_);
-    }
+    check_hash_ref($_[0]);
   },
   default => sub {
-    [];
+    {};
   }
 );
 sub op { 'read-item' } 
@@ -24,16 +21,19 @@ sub parse {
   my($class,$str_ref) = @_;
   my $xpath = xpath($str_ref);
 
+  my $op = op();
+
   my @z30;
 
-  for my $z($xpath->find('/read-item/z30')->get_nodelist()){
+  for my $z($xpath->find("/$op/z30")->get_nodelist()){
     push @z30,get_children($z,1);
   }    
 
   __PACKAGE__->new(
-    session_id => $xpath->findvalue('/read-item/session-id'),
-    error => $xpath->findvalue('/read-item/error'),
-    z30 => \@z30
+    session_id => $xpath->findvalue("/$op/session-id"),
+    errors => $class->parse_errors($xpath),
+    z30 => $z30[0],
+    content_ref => $str_ref
   );
 }
 
